@@ -1,3 +1,5 @@
+'use strict';
+
 const request = require('..');
 const https = require('https');
 const fs = require('fs');
@@ -519,7 +521,7 @@ describe('request(app)', function () {
         .get('/')
         .expect({ stringValue: 'foo', numberValue: 3, nestedObject: { innerString: 5 } })
         .end(function (err, res) {
-          err.message.should.equal('expected { stringValue: \'foo\',\n  numberValue: 3,\n  nestedObject: { innerString: 5 } } response body, got { stringValue: \'foo\',\n  numberValue: 3,\n  nestedObject: { innerString: \'5\' } }'); // eslint-disable-line max-len
+          err.message.should.equal('expected {\n  stringValue: \'foo\',\n  numberValue: 3,\n  nestedObject: { innerString: 5 }\n} response body, got {\n  stringValue: \'foo\',\n  numberValue: 3,\n  nestedObject: { innerString: \'5\' }\n}'); // eslint-disable-line max-len
 
           request(app)
             .get('/')
@@ -878,14 +880,15 @@ describe('agent.host(host)', function () {
     const agent = request.agent(app);
 
     app.get('/', function (req, res) {
-      res.send();
+      res.send({ hostname: req.hostname });
     });
 
     agent
       .host('something.test')
       .get('/')
       .end(function (err, res) {
-        err.hostname.should.equal('something.test');
+        if (err) return done(err);
+        res.body.hostname.should.equal('something.test');
         done();
       });
   });
